<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ast">
<context>
    <name>Plugin.DisplayName</name>
    <message>
        <location filename="../gui/monitor_plugin.cpp" line="60"/>
        <source>System Monitor</source>
        <translation>Supervisor del sistema</translation>
    </message>
</context>
<context>
    <name>Plugin.OpenSystemMontitor</name>
    <message>
        <location filename="../gui/monitor_plugin.cpp" line="147"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
</context>
<context>
    <name>Plugin.cpu</name>
    <message>
        <location filename="../gui/systemmonitortipswidget.cpp" line="85"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>Plugin.mem</name>
    <message>
        <location filename="../gui/systemmonitortipswidget.cpp" line="93"/>
        <source>MEM</source>
        <translation>MEM</translation>
    </message>
</context>
</TS>
